@@ -28,7 +28,8 @@ import shutil
 
 #default remote hwdb
 REMOTE_HWDB="/usr/share/lirc/lirc.hwdb"
-TRANSMITTER_HWDB="/usr/share/lirc/transmitter.hwdb"
+EXTRA_REMOTE_HWDB="/usr/share/lirc/extras/more_remotes.hwdb"
+TRANSMITTER_HWDB="/usr/share/lirc/extras/transmitter.hwdb"
 
 #path to hardware.conf
 HARDWARE_CONF="/etc/lirc/hardware.conf"
@@ -41,7 +42,7 @@ LIRCD_CONF="/etc/lirc/lircd.conf"
 
 class LircHandler:
 
-    def __init__(self,remote_hwdb=REMOTE_HWDB,transmitter_hwdb=TRANSMITTER_HWDB,hw_conf=HARDWARE_CONF):
+    def __init__(self,hw_conf=HARDWARE_CONF):
         #initialize all lists
         self.remote_list=[]
         self.remote="None"
@@ -57,25 +58,22 @@ class LircHandler:
         self.transmitter_driver=""
         self.transmitter_lircd_conf=""
         self.transmitter_count=0
-        #preload the data.  This can be overridden easily.
-        self.populate_devices("remote",remote_hwdb)
-        self.populate_devices("transmitter",transmitter_hwdb)
+        self.populate_devices("remote",REMOTE_HWDB)
+        self.populate_devices("remote",EXTRA_REMOTE_HWDB)
+        self.populate_devices("transmitter",TRANSMITTER_HWDB)
+        self.sort_devices()
         #load our current data
         self.read_hardware_conf(hw_conf)
 
+    def sort_devices(self):
+        """Sorts the device list for a type"""
+        self.remote_list.sort()
+        self.transmitter_list.sort()
+        self.remote_list.insert(0,"None")
+        self.transmitter_list.insert(0,"None")
+
     def populate_devices(self,type,file):
         """Populates all possible remotes from a hwdb.  Accepts either 'remote' or 'transmitter' for possible types"""
-        if type == "remote":
-            self.remote_count=1
-            self.remote_list=[]
-            self.remote_list.append("None")
-        elif type == "transmitter":
-            self.transmitter_count=1
-            self.transmitter_list=[]
-            self.transmitter_list.append("None")
-        else:
-            print "Unknown device type"
-            return
         try:
             hwdb = open(file).readlines()
             hwdb.sort()
@@ -83,6 +81,9 @@ class LircHandler:
             filter = "^\#|^\["
             #Filter out the /dev/input/eventX remote
             filter += "|http"
+            #Filter blaster if we are in remote
+            if type == 'remote':
+                filter += "|Blaster"
             pattern = re.compile(filter)
             for line in hwdb:
                 if pattern.search(line) is None:
@@ -98,12 +99,12 @@ class LircHandler:
                                 self.transmitter_count = self.transmitter_count + 1
         except IOError:
             print "Error reading " + file + " to parse remote listing."
-        if type == "remote":
-            self.remote_list.append("Custom") 
-            self.remote_count = self.remote_count + 1
-        elif type == "transmitter":
-            self.transmitter_list.append("Custom") 
-            self.transmitter_count = self.transmitter_count + 1
+        #if type == "remote":
+        #    self.remote_list.append("Custom") 
+        #    self.remote_count = self.remote_count + 1
+        #elif type == "transmitter":
+        #    self.transmitter_list.append("Custom") 
+        #    self.transmitter_count = self.transmitter_count + 1
 
     def set_device(self,device,type):
         """Sets an active remote control or transmitter"""
@@ -294,7 +295,7 @@ class LircHandler:
             os.putenv('DEBIAN_FRONTEND','gnome')
         else:
             os.putenv('DEBIAN_FRONTEND','noninteractive')
-        lirc_command = subprocess.Popen(["dpkg-reconfigure", "lirc"],stdout=subprocess.PIPE).communicate()[0]
+        lirc_command = subprocess.Popen(["/usr/sbin/dpkg-reconfigure", "lirc"],stdout=subprocess.PIPE).communicate()[0]
         print lirc_command
 
     def query_advanced(self,remote_hwdb_file=REMOTE_HWDB,transmitter_hwdb_file=TRANSMITTER_HWDB):
