@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# «mysql» - libmythbuntu class for mysql mangling
+# «mysql» - mythbuntu class for mysql mangling
 #
 # This script:
 # Copyright (C) 2007-2008, Mario Limonciello, for Mythbuntu
@@ -57,22 +57,51 @@ class MySQLHandler:
                     self.password= text
             in_f.close()
         except IOError:
-            print "Error reading " + file
+            print "Error reading %s" % file
 
-    def write_mysql_txt(self,file,rewrite=True):
+    def write_mysql_txt(self,file,debug=False):
         """Writes mysql.txt to a given file name"""
+        f_host = False
+        f_user = False
+        f_pass = False
+        f_db = False
         if os.path.exists(file):
-            if rewrite:
-                print "Moving " + file + " to " + file + ".old"
-                shutil.move(file, file + ".old")
-            else:
-                print "Ignoring rewrite due to user request"
-                return
-        out_f = open(file, "w")
-        out_f.write("DBHostName=" + self.server + "\n")
-        out_f.write("DBUserName=" + self.user + "\n")
-        out_f.write("DBName=" + self.database + "\n")
-        out_f.write("DBPassword=" + self.password + "\n")
+            print "Copying %s to %s~" % (file,file)
+            shutil.copy(file, file + "~")
+            in_f = open(file + "~", 'r')
+            out_f = open(file, "w")
+            for line in in_f:
+                if line.startswith("DBHostName"):
+                    if not f_host:
+                        out_f.write("DBHostName=" + self.server + "\n")
+                        f_host = True
+                elif line.startswith("DBUserName"):
+                    if not f_user:
+                        out_f.write("DBUserName=" + self.user + "\n")
+                        f_user = True
+                elif line.startswith("DBName"):
+                    if not f_db:
+                        out_f.write("DBName=" + self.database + "\n")
+                        f_db = True
+                elif line.startswith("DBPassword"):
+                    if not f_pass:
+                        out_f.write("DBPassword=" + self.password + "\n")
+                        f_pass = True
+                else:
+                    out_f.write(line)
+            in_f.close()
+            if not debug:
+                os.remove(file + "~")
+        else:
+            out_f = open(file, "w")
+        if not f_host:
+            out_f.write("DBHostName=" + self.server + "\n")
+        if not f_user:
+            out_f.write("DBUserName=" + self.user + "\n")
+        if not f_db:
+            out_f.write("DBName=" + self.database + "\n")
+        if not f_pass:
+            out_f.write("DBPassword=" + self.password + "\n")
         out_f.close()
 
     def toggle_mysql_service_config(self,enable):
@@ -114,7 +143,7 @@ class MySQLHandler:
 
     def restart_mysql_service(self):
         """Restarts MySQL service"""
-        start_mysql = subprocess.Popen(["invoke-rc.d", "mysql", "restart"],stdout=subprocess.PIPE).communicate()[0]
+        start_mysql = subprocess.Popen(["/usr/sbin/invoke-rc.d", "mysql", "restart"],stdout=subprocess.PIPE).communicate()[0]
         print start_mysql
 
     def update_config(self,config):
@@ -128,32 +157,39 @@ class MySQLHandler:
         """Returns our currently stored configuration"""
         return {"user":self.user,"password":self.password,"server":self.server,"database":self.database}
 
-    def reset_user_password(self,admin_user,admin_pass,password):
+    def reset_user_password(self,admin_pass,password):
         """Resets a user's password if it was forgotten"""
+        commands = ["UPDATE user SET Password=PASSWORD('"+password+"') WHERE user=mythtv')",
+        "FLUSH PRIVILEGES"]
+        if self.run_mysql_commands(commands,mysql_user="root"):
+            return "Successful"
+        else:
+            return "Failure"
+
+    def run_mysql_commands(self,commands,mysql_user=None):
+        """Runs mysql command(s) and returns the response"""
+        if mysql_user is None:
+            mysql_user = self.user
         try:
-            db = MySQLdb.connect(host=self.server, user=admin_user, passwd=admin_pass,db=self.database)
+            db = MySQLdb.connect(host=self.server, user=mysql_user, passwd=self.password,db=self.database)
             cursor = db.cursor()
-            cursor.execute("UPDATE user SET Password=PASSWORD('"+password+"') WHERE user="+self.user+"')")
-            result = cursor.fetchone()
-            cursor.execute("FLUSH PRIVILEGES")
-            result = cursor.fetchone()
+            if type(commands) is list:
+                for command in commands:
+                    cursor.execute(command)
+                    result = cursor.fetchone()
+            elif type(commands) is str:
+                result = cursor.execute(commands)
+            else:
+                print "Unknown type"
             cursor.close()
             db.close()
-            result = "Successful"
         except:
-            result = "Failure"
+            result = False
         return result
 
     def do_connection_test(self):
         """Tests to make sure that the backend is accessible"""
-        try:
-            db = MySQLdb.connect(host=self.server, user=self.user, passwd=self.password,db=self.database)
-            cursor = db.cursor()
-            cursor.execute("SELECT NULL")
-            result = cursor.fetchone()
-            cursor.close()
-            db.close()
-            result = "Successful"
-        except:
-            result = "Failure"
-        return result
+        if self.run_mysql_commands("SELECT NULL"):
+            return "Successful"
+        else:
+            return "Failure"
